<?php
	/*
	 * date.php - version 0.1.2 2006/01/31
	 * 
	 * Description:
	 * Class for working with dates adapted for local climate.
	 * Use date in timestamp14 format. ("yyyymmddHHiiss" or "yyyy-mm-dd HH:ii:ss")
	 *
	 * Author: 
	 * Oliver Petkovic <oliver78@verat.net>
	 *
	 * Licence:
	 * Free
	 */

class Date
{
	var $mTimeStamp;
	var $mYear; 
	var $mMonth;
	var $mDay;
	var $mHour;
	var $mMinute;
	var $mSecond;
	var $mTimeZone;
	var $mFormat;
		
	//
	//	Default Constructor
	//  
	
	function Date()
	{
		$this->mTimeStamp = date("YmdHis");
		$this->mTimeZone = 0;
		$this->mFormat = 0;
		$this->MakeDate();
	}
	
	//
	// Set Functions
	//
	
	function SetTimeStamp($timeStamp)
	{
		if (strlen($timeStamp)== 14)
		{
			$this->SetFormat(0);
			$this->mTimeStamp = $timeStamp;
		}
		else 
		if (strlen($timeStamp)== 19)
		{
			$this->SetFormat(1);
			$this->mTimeStamp = $timeStamp;
		}
		else 
			echo "<b>(class Date)</b> <b>Error:</b> Wrong parameter in SetTimeStamp()<br />";
	}
	
	function SetFormat($number)
	{
		if ($number!=0 and $number!=1)
			echo "<b>(class Date)</b> <b>Error:</b> Wrong parameter in SetMysqlVersion()<br />";
		else 
			$this->mFormat =  $number;
	}
	
	function SetServerTimeZone($timeZone)
	{
		if (($timeZone < -12) || ($timeZone > 12)) 
			echo "<b>(class Date)</b> <b>Error:</b> Wrong parameter in SetServerTimeZone()<br />";
		else 
			$this->mTimeZone = $timeZone;
	}
	
	//
	// Parsing
	//
	function Parsing()
	{
		if ($this->mFormat == 0)
		{
			// year
			$this->mYear = substr($this->mTimeStamp, 0, 4);
			//month
			$this->mMonth = substr($this->mTimeStamp, 4, 2);			
			// day
			$this->mDay = substr($this->mTimeStamp, 6, 2);
			// hour
			$this->mHour = substr($this->mTimeStamp, 8, 2);
			// minute
			$this->mMinute = substr($this->mTimeStamp, 10, 2);
			// second
			$this->mSecond = substr($this->mTimeStamp, 12, 2);
		}
		else 
		
		if ($this->mFormat == 1)
		{
			// year
			$this->mYear = substr($this->mTimeStamp, 0, 4);
			//month
			$this->mMonth = substr($this->mTimeStamp, 5, 2);
			// day
			$this->mDay = substr($this->mTimeStamp, 8, 2);
			// hour
			$this->mHour = substr($this->mTimeStamp, 11, 2);
			// minute
			$this->mMinute = substr($this->mTimeStamp, 14, 2);
			// second
			$this->mSecond = substr($this->mTimeStamp, 17, 2);
		}
	}
	
	function MakeDate()
	{	
		$this->Parsing();
		
		// hour shifting
		$this->mHour = $this->mHour + $this->mTimeZone;
			
		// 
		$this->mYear = date("Y", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		$this->mMonth = date("m", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		$this->mDay = date("d", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		$this->mHour = date("H", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		$this->mMinute = date("i", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		$this->mSecond = date("s", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		return true;
	}
	
	//
	// Get functions
	//
	
	function GetTimeStamp()
	{
		return $this->mTimeStamp;
	}
	
	function GetTimeZone()
	{
		return $this->mTimeZone;
	}
	
	function GetFormat()
	{
		return $this->mFormat;
	}
	
	function GetYear()
	{
		return $this->mYear;
	}
	
	function GetMonth()
	{
		return $this->mMonth;
	}
	
	function GetDay()
	{
		return $this->mDay;
	}
	
	function GetHour()
	{
		return $this->mHour;
	}
	
	function GetMinute()
	{
		return $this->mMinute;
	}

	function GetSecond()
	{
		return $this->mSecond;
	}
	
	//
	//	Function GetTime() returns time in (hh:mm) format.
	//
	function GetTime()
	{
		$time = date("H:i", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		return $time;
	}
	
	//
	//	Function GetFullTime() returns time in (hh:mm:ss) format.
	//
	function GetTimeFull()
	{
		$time = date("H:i:s", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		return $time;
	}
	
  	//
	// Function GetDate() returns date in (dd. mm. yyyy.) format.
	//
	function GetDate()
	{
		$date = date("dmY", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		$this->mDay = substr($date, 0, 2);
		$this->mMonth = substr($date, 2, 2);
		$this->mYear = substr($date, 4, 4);
		$array = array($this->mDay,". ",$this->mMonth,". ",$this->mYear,".");
		$date = implode("", $array);
		return $date;
	}
	
	//
	// Function GetDateFull() returns date in (dd. month yyyy.) format. (month = name of the month)
	//
	function GetDateFull()
	{
		$date = date("dmY", mktime($this->mHour, $this->mMinute, $this->mSecond, $this->mMonth, $this->mDay, $this->mYear));
		$this->mDay = substr($date, 0, 2);
		$this->mMonth = substr($date, 2, 2);
		$this->mYear = substr($date, 4, 4);
			
		// coversion
		switch($this->mMonth)
		{
			case "01": $this->mMonth = "januar";	break;
			case "02": $this->mMonth = "februar";	break;
			case "03": $this->mMonth = "mart";		break;
			case "04": $this->mMonth = "april";		break;
			case "05": $this->mMonth = "maj";		break;
			case "06": $this->mMonth = "jun";		break;
			case "07": $this->mMonth = "juli";		break;
			case "08": $this->mMonth = "avgust";	break;
			case "09": $this->mMonth = "septembar";	break;
			case "10": $this->mMonth = "oktobar";	break;
			case "11": $this->mMonth = "novembar";	break;
			case "12": $this->mMonth = "decembar";	break;
		}
			
		// conversion (releasing the leading zero)
		switch($this->mDay)
		{
			case "01": $this->mDay=1;	break;
			case "02": $this->mDay=2;	break;
			case "03": $this->mDay=3;	break;
			case "04": $this->mDay=4;	break;
			case "05": $this->mDay=5;	break;
			case "06": $this->mDay=6;	break;		
			case "07": $this->mDay=7;	break;
			case "08": $this->mDay=8;	break;
			case "09": $this->mDay=9;	break;
		}
		
		$array = array($this->mDay,". ",$this->mMonth, " ",$this->mYear,".");
		$date = implode("", $array);
		return $date;		
	}
}
?>